<?php

namespace Drupal\simple_survey\Entity;

use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * Provides an interface for defining Survey Response entities.
 *
 * @ingroup simple_survey
 */
interface SimpleSurveyInterface extends ConfigEntityInterface {

  /**
   * Checks if the entered paths match the current path.
   *
   * @param string|null $path
   *   The current aliased path.
   *
   * @return bool
   *   Returns true if a match is found false if not.
   */
  public function checkPath(string $path = NULL);

  /**
   * Checks survey is active.
   *
   * @return bool
   *   Returns true if survey is active false if inactive.
   */
  public function isSurveyActive();

  /**
   * Checks if request to load a survey is valid and should be loaded displayed.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The survey request.
   *
   * @return mixed
   *   The returned response.
   */
  public function validate(Request $request);

  /**
   * Generates a Cookie for tracking.
   *
   * @param string $uuid
   *   Cookie user identification.
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The current request.
   *
   * @return \Symfony\Component\HttpFoundation\Cookie
   *   The cookie name.
   */
  public function generateSurveyCookie(string $uuid, Request $request, Response &$response);

  /**
   * Gets the cookie value from the current request.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The current request.
   *
   * @return string
   *   The user id.
   */
  public function getCookieValue(Request $request);

}
